import chronoptics.tof as tof
import numpy as np

cam = tof.KeaCamera(serial="202001a")

cal = cam.getCalibration()

print(
    "Lens matrix {} distortion coefficients {}".format(
        cal.getDepthCameraMatrix(), cal.getDepthDistortionCoefficients()
    )
)

config = cam.getCameraConfig()
config.reset()

# Manually configure camera configuration
config.setModulationFrequency(0, 80.0)
config.setPhaseShifts(0, [0.0, 0.25, 0.375, 0.625])
config.setIntegrationTime(0, [300, 300, 300, 300])
config.setDutyCycle(0, 0.35)

config.addFrame()
config.setModulationFrequency(1, 100.0)
config.setPhaseShifts(1, [0.0, 0.25, 0.375, 0.625])
config.setIntegrationTime(1, [300, 300, 300, 300])
config.setDutyCycle(1, 0.35)

# Manually configure processing configuration
proc_config = tof.ProcessingConfig()
proc_config.setTemporalEnabled(True)
proc_config.setMedianEnabled(True)
proc_config.setPhaseUnwrappingEnabled(True)
proc_config.setPhaseUnwrappingMaxOffset(np.pi / 2)
proc_config.setFlyingEnabled(True)

cam.setConfigurations(config, proc_config)

tof.selectStreams(cam, [tof.FrameType.RADIAL, tof.FrameType.INTENSITY])

cam.start()
frames = cam.getFrames()
cam.stop()
